@@ -20,10 +20,10 @@ def smape(data: pd.DataFrame, prediction: str, actuals: str):
 def mase(data: pd.DataFrame, prediction: str, actuals: str, step_size: int = 1):
     data = data[[prediction, actuals]].copy()
     # add a small amount to avoid dividing by 0
-    data['abs_shifted_error'] = abs(data[actuals] - data[actuals].shift(step_size)) + 0.01
-    data['abs_prediction_error'] = abs(data[actuals] - data[prediction])
+    data["abs_shifted_error"] = abs(data[actuals] - data[actuals].shift(step_size)) + 0.01
+    data["abs_prediction_error"] = abs(data[actuals] - data[prediction])
 
-    avg_shifted_error = data[~data['abs_shifted_error'].isna()]['abs_shifted_error'].sum() / (len(data) - step_size)
-    data['abs_scaled_error'] = data['abs_prediction_error'] / avg_shifted_error
+    avg_shifted_error = data[~data["abs_shifted_error"].isna()]["abs_shifted_error"].sum() / (len(data) - step_size)
+    data["abs_scaled_error"] = data["abs_prediction_error"] / avg_shifted_error
 
-    return data['abs_scaled_error'].mean()
\ No newline at end of file
+    return data["abs_scaled_error"].mean()
